#!/usr/bin/env rspec -cfd -b
# vim: set noet nosta sw=4 ts=4 :

require_relative '../../helpers'

begin
	require 'roda'
	$roda_support = true
rescue LoadError => err
	warn "Roda support testing disabled: %p: %s" % [ err.class, err.message ]
	$roda_support = false
end


RSpec.describe "Roda support", :if => $roda_support do
	include Rack::Test::Methods if defined?( ::Rack )

	before( :all ) do
		setup_logging( :fatal )
	end

	before( :each ) do
		allow( Inversion::Template ).to receive( :load ).and_return( tmpl )
		app.app # looks weird, but creates an instance for Rack::Test.
	end

	let( :tmpl ) { Inversion::Template.new("Hi <?attr name ?>!") }

	let( :app ) do
		Class.new( Roda ) do
			plugin :inversion
			templates \
				tmpl: 'template.tmpl'

			route do |r|
				r.get "symbol" do
					:tmpl
				end

				r.get "unknown" do
					template( :nope )
				end

				r.get "template" do
					tmpl = template( :tmpl )
					tmpl.name = "handsome"
					return tmpl
				end
			end
		end
	end


	it "registers itself with Roda on demand" do
		plugs = Roda::RodaPlugins.instance_variable_get( :@plugins )
		expect( plugs[:inversion] ).to be( Roda::RodaPlugins::Inversion )
	end


	it "extends the Roda DSL with a #template helper method" do
		expect( app.instance_methods ).to include( :template )
	end


	it "falls through to Roda default behavior on unmapped symbols" do
		get '/nonexistent'
		expect( last_response ).to_not be_ok
	end


	it "can reference a known template via symbol" do
		get '/symbol'
		expect( last_response ).to be_ok
		expect( last_response.body ).to eq( 'Hi !' )
	end


	it "can render a returned template via template()" do
		get '/template'
		expect( last_response ).to be_ok
		expect( last_response.body ).to eq( 'Hi handsome!' )
	end


	it "fails fast if referencing an unknown template at runtime" do
		expect {
			get '/unknown'
		}.to raise_error( ArgumentError, /no :nope template registered/ )
	end
end

